==> NewsReaderPortlet-5.1.0-sources.jar: org/jasig/portlet/newsreader/adapter/RomeAdapterRetryHandler.java <==
/**
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.jasig.portlet.newsreader.adapter;

import java.io.IOException;
import java.net.SocketException;
import java.net.SocketTimeoutException;

import org.apache.http.NoHttpResponseException;
import org.apache.http.impl.client.DefaultHttpRequestRetryHandler;
import org.apache.http.protocol.HttpContext;

public class RomeAdapterRetryHandler extends DefaultHttpRequestRetryHandler{

    private int timesToRetry;

    public RomeAdapterRetryHandler (int timesToRetry) {
        super(timesToRetry, true);
    }

    @Override
    public boolean retryRequest(IOException exception, int executionCount, HttpContext context) {
        if (executionCount >= timesToRetry) {
            // Do not retry if over max retry count
            return false;
        }
        if (exception instanceof NoHttpResponseException) {
            // Retry if the server dropped connection on us
            return true;
        }
        if (exception instanceof SocketException) {
            // Retry if the server reset connection on us
            return true;
        }
        if (exception instanceof SocketTimeoutException) {
            // Retry if the read timed out
            return true;
        }
        return super.retryRequest(exception, executionCount, context);
    }

}

==> NewsReaderPortlet-5.1.1-sources.jar: org/jasig/portlet/newsreader/adapter/RomeAdapterRetryHandler.java <==
/*
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.jasig.portlet.newsreader.adapter;

import java.io.IOException;
import java.net.SocketException;
import java.net.SocketTimeoutException;

import org.apache.http.NoHttpResponseException;
import org.apache.http.impl.client.DefaultHttpRequestRetryHandler;
import org.apache.http.protocol.HttpContext;

/**
 * <p>RomeAdapterRetryHandler class.</p>
 *
 * @author bgonzalez
 * @since 5.1.1
 */
public class RomeAdapterRetryHandler extends DefaultHttpRequestRetryHandler{

    private int timesToRetry;

    /**
     * <p>Constructor for RomeAdapterRetryHandler.</p>
     *
     * @param timesToRetry a int
     */
    public RomeAdapterRetryHandler (int timesToRetry) {
        super(timesToRetry, true);
    }

    /** {@inheritDoc} */
    @Override
    public boolean retryRequest(IOException exception, int executionCount, HttpContext context) {
        if (executionCount >= timesToRetry) {
            // Do not retry if over max retry count
            return false;
        }
        if (exception instanceof NoHttpResponseException) {
            // Retry if the server dropped connection on us
            return true;
        }
        if (exception instanceof SocketException) {
            // Retry if the server reset connection on us
            return true;
        }
        if (exception instanceof SocketTimeoutException) {
            // Retry if the read timed out
            return true;
        }
        return super.retryRequest(exception, executionCount, context);
    }

}
